@@ -147,8 +147,16 @@ def convert(filename, args):
         ]
     else:
         audio_opts = config.audio_encoder_opts + [
-            '-b:a', '160K'
+            '-b:a'
         ]
+        if info.audio.channel_s >= 6:
+            audio_opts.append('320K')
+        else:
+            audio_opts.append('160K')
+
+    subtitle_opts = [
+        '-codec:s', 'copy'
+    ]
 
     input_ops = [
         '-i', '%s' % filename,
@@ -159,17 +167,18 @@ def convert(filename, args):
     sys.stderr.write('Encoding %s -> %s\n' % (filename, out_file_name))
 
     if os.path.exists(out_path):
-        sys.stderr.write('Destination file exists, skipping...')
+        print('Destination file exists, skipping...')
+        return
 
     if method == '1pass':
-        opts = input_ops + video_opts + audio_opts + [
+        opts = input_ops + video_opts + audio_opts + subtitle_opts + [
             '-y',
             out_path
         ]
-        progress = EncodingProgress('Pass 1 of 1:', info.video.frame_count)
         if args.dry_run:
             print 'ffmpeg ' + ' '.join(opts)
         else:
+            progress = EncodingProgress('Pass 1 of 1:', info.video.frame_count)
             p = sh.ffmpeg(
                 *opts,
                 _err=progress.process_ffmpeg_line,
@@ -178,7 +187,6 @@ def convert(filename, args):
             p.wait()
             progress.finish()
     elif method == '2pass':
-        pass1_progress = EncodingProgress('Pass 1 of 2: ', info.video.frame_count)
         opts = input_ops + video_opts + [
             '-an',
             '-pass', '1',
@@ -189,6 +197,10 @@ def convert(filename, args):
         if args.dry_run:
             print 'ffmpeg ' + ' '.join(opts)
         else:
+            pass1_progress = EncodingProgress(
+                'Pass 1 of 2: ',
+                info.video.frame_count
+            )
             p = sh.ffmpeg(
                 *opts,
                 _err=pass1_progress.process_ffmpeg_line,
@@ -197,11 +209,7 @@ def convert(filename, args):
             p.wait()
             pass1_progress.finish()
 
-        pass2_progress = EncodingProgress(
-            'Pass 2 of 2: ',
-            info.video.frame_count
-        )
-        opts = input_ops + video_opts + audio_opts + [
+        opts = input_ops + video_opts + audio_opts + subtitle_opts + [
             '-pass', '2',
             '-y',
             out_path
@@ -209,6 +217,10 @@ def convert(filename, args):
         if args.dry_run:
             print 'ffmpeg ' + ' '.join(opts)
         else:
+            pass2_progress = EncodingProgress(
+                'Pass 2 of 2: ',
+                info.video.frame_count
+            )
             p = sh.ffmpeg(
                 *opts,
                 _err=pass2_progress.process_ffmpeg_line,
@@ -236,19 +248,22 @@ def check_required_programs():
         )
 
     out = StringIO()
-    sh.ffmpeg(
-        '-encoders',
-        _out=out
-    )
+    try:
+        sh.ffmpeg(
+            '-encoders',
+            _out=out
+        )
+    except sh.ErrorReturnCode:
+        print (
+            '%s: unsupported version of ffmpeg installed. '
+            'Install ffmpeg version 1.0 or higher'
+        ) % PROG_NAME
 
     if 'libx264' not in out.getvalue():
-        print ''
         print (
-            "%s: Installed version of ffmeg doesn't include libx264 support."
+            "%s: Installed version of ffmeg doesn't include libx264 support. "
             "Install version of ffmpeg that supports libx264."
-        ) % (
-            PROG_NAME
-        )
+        ) % PROG_NAME
         exit(1)
 
     if 'libfaac' in out.getvalue():
@@ -297,7 +312,7 @@ def main():
     )
 
     args = parser.parse_args()
-    input_file = args.input_file.strip()
+    input_file = os.path.abspath(args.input_file.strip())
     if not os.path.exists(input_file):
         print '%s: %s: No such file or directory' % (PROG_NAME, input_file)
         exit(1)
